@@ -1,12 +1,16 @@
-from __future__ import absolute_import
 # copyright openpyxl 2010-2015
 
+from copy import copy
 from keyword import kwlist
 KEYWORDS = frozenset(kwlist)
 
 from . import Descriptor
 from . import _Serialiasable
-from .sequence import Sequence, NestedSequence
+from .sequence import (
+    Sequence,
+    NestedSequence,
+    MultiSequencePart,
+)
 from .namespace import namespaced
 
 from openpyxl.compat import safe_string
@@ -58,6 +62,10 @@ class Serialisable(_Serialiasable):
             elif key in KEYWORDS:
                 attrib["_" + key] = attrib[key]
                 del attrib[key]
+            elif "-" in key:
+                n = key.replace("-", "_")
+                attrib[n] = attrib[key]
+                del attrib[key]
 
         if node.text and "attr_text" in cls.__attrs__:
             attrib["attr_text"] = node.text
@@ -86,6 +94,9 @@ class Serialisable(_Serialiasable):
             elif isinstance(desc, Sequence):
                 attrib.setdefault(tag, [])
                 attrib[tag].append(obj)
+            elif isinstance(desc, MultiSequencePart):
+                attrib.setdefault(desc.store, [])
+                attrib[desc.store].append(obj)
             else:
                 attrib[tag] = obj
 
@@ -117,6 +128,8 @@ class Serialisable(_Serialiasable):
         for child_tag in self.__elements__:
             desc = getattr(self.__class__, child_tag, None)
             obj = getattr(self, child_tag)
+            if hasattr(desc, "namespace") and hasattr(obj, 'namespace'):
+                obj.namespace = desc.namespace
 
             if isinstance(obj, seq_types):
                 if isinstance(desc, NestedSequence):
@@ -149,6 +162,10 @@ class Serialisable(_Serialiasable):
             value = getattr(self, attr)
             if attr.startswith("_"):
                 attr = attr[1:]
+            elif attr != "attr_text" and "_" in attr:
+                desc = getattr(self.__class__, attr)
+                if getattr(desc, "hyphenated", False):
+                    attr = attr.replace("_", "-")
             if attr != "attr_text" and value is not None:
                 yield attr, safe_string(value)
 
@@ -209,3 +226,15 @@ class Serialisable(_Serialiasable):
             else:
                 vals[el] = a or b
         return self.__class__(**vals)
+
+
+    def __copy__(self):
+        # serialise to xml and back to avoid shallow copies
+        xml = self.to_tree(tagname="dummy")
+        cp = self.__class__.from_tree(xml)
+        # copy any non-persisted attributed
+        for k in self.__dict__:
+            if k not in self.__attrs__ + self.__elements__:
+                v = copy(getattr(self, k))
+                setattr(cp, k, v)
+        return cp
